@@ -17,6 +17,8 @@ class ProtectionRule(Ppdm):
             self.msg = ""
             self.failure = False
             self.fail_msg = ""
+            self.fail_response = {}
+            self.fail_body = {}
             self.name = kwargs['name']
             self.body = {}
             self.target_body = {}
@@ -55,6 +57,7 @@ class ProtectionRule(Ppdm):
             elif return_body.success is False:
                 self.failure = True
                 self.fail_msg = return_body.msg
+                self.fail_response = return_body.response
         self.get_rule()
 
     def create_rule(self, **kwargs):
@@ -79,6 +82,7 @@ class ProtectionRule(Ppdm):
             elif return_body.success is False:
                 self.failure = True
                 self.fail_msg = return_body.msg
+                self.fail_response = return_body.response
         elif self.exists:
             self.msg = f"Protection Rule {self.name} already exists"
         self.get_rule()
@@ -100,6 +104,8 @@ class ProtectionRule(Ppdm):
             elif return_body.success is False:
                 self.failure = True
                 self.fail_msg = return_body.msg
+                self.fail_response = return_body.response
+                self.fail_body = (self.body.copy()).update(self.target_body)
         self.target_body = {}
         self.get_rule()
 
@@ -178,8 +184,9 @@ class ProtectionRule(Ppdm):
     def __update_protection_rule(self):
         protectionrule_logger.debug("Method: update_protection_rule")
         return_body = helpers.ReturnBody()
+        future_body = self.body.update(self.target_body)
         response = super()._rest_put("/protection-rules"
-                                     f"/{self.id}", self.target_body)
+                                     f"/{self.id}", future_body)
         if response.ok:
             msg = f"Protection Rule id \"{self.name}\" successfully updated"
             return_body.success = True
